<?php
/**
 *	Line In Settings API with menu page base class
 *
 *	@version 0.1.2
 */

if ( !class_exists('LIPBC_Settings_API_With_Page') ) {
	
	abstract class LIPBC_Settings_API_With_Page  {
		public 	$options = array();

		function __construct($add_settings_link = false) {
			if ( $add_settings_link ) {
				if ( $this->plugin_basename ) {
					add_filter("plugin_action_links_" . $this->plugin_basename, array( &$this, 'add_settings_link' ) );
				} else {
					wp_die( "Plugin basename not set" );
				}
			} 
			add_action('admin_init', array( &$this, 'register_settings') );
			add_action('admin_init', array( &$this, 'add_settings_section') );
			// Set up default options

			add_action('init', array( &$this, 'options_init'), 9 );
						
		}
		
		function register_settings() {
			register_setting( $this->options_name, $this->options_name, array( &$this, 'validate' ) );
		}

		function options_init() {
	
		     // set options equal to defaults
		     $this->options = get_option( $this->options_name );

		     if ( false === $this->options ) {

				$this->options = $this->get_default_options();

		     }
		     update_option( $this->options_name, $this->options );

			
		}
		
		// Adds a settings link to the Activate Plugins page
		public function add_settings_link($links) { 
			$settings_link = '<a href="options-general.php?page=' . $this->plugin_id . '">Settings</a>'; 
			array_unshift($links, $settings_link); 
			return $links; 
		}
		
		// Add full menu page
		public function add_menu_page( $title, $id, $icon_url = false, $position = false ) {
			$options_page = add_menu_page( $title, $title, 'manage_options', $id, array( &$this, 'page_html'), $icon_url, $position );		

			add_contextual_help( $options_page, $this->_help() );
			
		}
		
		
		// Add submenu page
		public function add_submenu_page() {
			if ( $this->plugin_id && isset( $this->parent_page ) ) {
				$options_page = add_submenu_page($this->parent_page, __( $this->plugin_title, $this->lang ), __( $this->plugin_title, $this->lang ), 'manage_options', $this->plugin_id, array( &$this, 'page_html') );
			} else {
				wp_die("You've failed to define your parent page");
			}
			
			
			// For adding admin-only styles and scripts
			// add_action('admin_print_styles-' . $options_page, array( &$this, 'enqueue_styles') );
			// add_action('admin_print_styles-widgets.php', array( &$this, 'enqueue_styles') );
			add_action('admin_print_styles-' . $options_page, array( &$this, 'enqueue_scripts') );						
			
			if ( ! $options_page )
				return;
			add_contextual_help( $options_page, $this->_help() );
			
		}
		
		
		public function load_scripts( $file_name, $deps = false, $ver ) {
			wp_register_script( $this->plugin_id . '-scripts', $this->scripts_url  . $file_name . '.js', $deps, $ver, true );
		}
		public function load_styles( $file_name, $deps = false, $ver ) {
			wp_register_style( $this->plugin_id . '-styles', $this->styles_url  . $file_name . '.css', $deps, $ver, 'all');
		}
		
		public function enqueue_scripts() {
			wp_enqueue_script( $this->plugin_id . '-scripts' );
		}
		
		public function enqueue_styles() {
			wp_enqueue_style( $this->plugin_id . '-styles' );
		}
		
		public function _help() {
			return false;
		}
		
		public function page_html() {
			?>
			<div class='wrap'>
				<?php screen_icon(); ?>
				<h2><?php _e( $this->plugin_title,  $this->lang ); ?></h2>
				<?php /*
					if ( isset( $_GET['settings-updated'] ) ) {
					    echo "<div class='updated'><p>Settings updated successfully.</p></div>";
					}
					*/
				 ?>
				 <form action="options.php" method="post">
					 <?php
						settings_fields($this->options_name);
						do_settings_sections($this->plugin_id);
						
						
					 ?>
					 <p class='submit'><?php submit_button('Update options', 'primary','submit', false); ?> <?php submit_button('Reset options', 'secondary', 'reset', false); ?></p>

				 </form>
			</div> <?php
		}
		
		/* Need to set some default options for this to work */
		abstract public function get_default_options();
		abstract public function validate( $input );
		abstract public function add_settings_section();
	}
}


?>